@@ -5,11 +5,9 @@
 pub use event_context::EventContext;
 pub use i_event::IEvent;
 pub use i_event_consumer::IEventConsumer;
-pub use i_event_dispatcher::IEventDispatcher;
 pub use i_event_handler::IEventHandler;
 
 mod event_context;
 mod i_event;
 mod i_event_consumer;
-mod i_event_dispatcher;
 mod i_event_handler;
