@@ -9,13 +9,11 @@
 
 pub use aggregate::*;
 pub use commands::*;
-pub use dispatchers::*;
 pub use events::*;
 pub use queries::*;
 
 mod aggregate;
 mod commands;
-mod dispatchers;
 mod events;
 mod queries;
 
