@@ -2,12 +2,15 @@
 #![deny(missing_docs)]
 #![deny(clippy::all)]
 #![warn(rust_2018_idioms)]
-// #![warn(clippy::pedantic,missing_debug_implementations)]
+#![warn(
+    clippy::pedantic,
+    //missing_debug_implementations
+)]
 
 //! # cqrs-es2
 //!
-//! **A Rust library providing lightweight CQRS and event sourcing
-//! framework.**
+//! A Rust library providing lightweight CQRS and event sourcing
+//! framework.
 //!
 //! [![Publish](https://github.com/brgirgis/cqrs-es2/actions/workflows/crates-io.yml/badge.svg)](https://github.com/brgirgis/cqrs-es2/actions/workflows/crates-io.yml)
 //! [![Test](https://github.com/brgirgis/cqrs-es2/actions/workflows/rust-ci.yml/badge.svg)](https://github.com/brgirgis/cqrs-es2/actions/workflows/rust-ci.yml)
@@ -17,12 +20,26 @@
 //!
 //! ---
 //!
+//! Provides all basic interfaces for the CQRS system.
+//!
+//! ## Installation
+//!
+//! ```toml
+//! [dependencies]
+//! # serialization
+//! serde = { version = "^1.0.127", features = ["derive"] }
+//! serde_json = "^1.0.66"
+//!
+//! # CQRS framework
+//! cqrs-es2 = { version = "*"}
+//! ```
+//!
 //! ## Usage
 //!
 //! Full fledged demo applications:
 //!
-//! - [RESTful](https://github.com/brgirgis/cqrs-restful-demo).
-//! - [gRPC](https://github.com/brgirgis/cqrs-grpc-demo).
+//! - Sync [RESTful](https://github.com/brgirgis/cqrs-es2-store/tree/master/examples/restful)
+//! - Async [gRPC](https://github.com/brgirgis/tokio-cqrs-es2-store/tree/master/examples/grpc)
 
 pub use crate::{
     aggregates::*,
@@ -30,31 +47,26 @@ pub use crate::{
     errors::*,
     events::*,
     queries::*,
-    stores::*,
     test_framework::*,
 };
 
-// Errors module holds the library error types.
+/// Errors module holds the library error types.
 mod errors;
 
-// Aggregates module holds the central traits that define the
-// fundamental component of CQRS.
+/// Aggregates module holds the central traits that define the
+/// fundamental component of CQRS.
 mod aggregates;
 
-// Commands module provides the abstract domain commands.
+/// Commands module provides the abstract domain commands.
 mod commands;
 
-// Events module provides the abstract domain events and associated
-// wrapper.
+/// Events module provides the abstract domain events and associated
+/// wrapper.
 mod events;
 
-// Stores module holds the abstract `EventStore` trait as well as an
-// in-memory implementation.
-mod stores;
-
-// Queries module provides the basic downstream query objects needed
-// to render queries (or "views") that describe the state of the
-// system.
+/// Queries module provides the basic downstream query objects needed
+/// to render queries (or "views") that describe the state of the
+/// system.
 mod queries;
 
 /// Test provides a test framework for building a resilient test base
